# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "",
    "Also available in:": "Διαθέσιμο και στα:",
    "Archive": "Αρχείο",
    "Categories": "Κατηγορίες",
    "Comments": "",
    "LANGUAGE": "Ελληνικά",
    "Languages:": "",
    "More posts about %s": "Περισσότερες αναρτήσεις για %s",
    "Newer posts": "Νεότερες αναρτήσεις",
    "Next post": "Επόμενη ανάρτηση",
    "No posts found.": "",
    "Nothing found.": "",
    "Older posts": "Παλαιότερες αναρτήσεις",
    "Original site": "Ιστοσελίδα αρχικής ανάρτησης",
    "Posted:": "Αναρτήθηκε:",
    "Posts about %s": "Αναρτήσεις για %s",
    "Posts for year %s": "Αναρτήσεις για το έτος %s",
    "Posts for {month} {year}": "Αναρτήσεις για τον {month} του {year}",
    "Previous post": "Προηγούμενη ανάρτηση",
    "Publication date": "",
    "RSS feed": "",
    "Read in English": "Διαβάστε στα Ελληνικά",
    "Read more": "Διαβάστε περισσότερα",
    "Source": "Πηγαίος κώδικας",
    "Tags and Categories": "Ετικέτες και κατηγορίες",
    "Tags": "Ετικέτες",
    "old posts, page %d": "σελίδα παλαιότερων αναρτήσεων %d",
    "page %d": "σελίδα %d",
}
